@@ -1,5 +1,7 @@
-pub mod connect;
+pub mod compaction;
+pub mod new;
 pub mod delete;
+pub mod flush;
 pub mod get_all;
 pub mod get;
 pub mod put;
\ No newline at end of file
